
## 0.2.0 (2025-03-27)

* drop python 3.8 support
* add python 3.13 support

## 0.1.6 (2024-10-07)

* update numpy version in build-system

## 0.1.5 (2024-06-26)

* add **numpy 2.0** build

## 0.1.4 (2024-06-18)

* limit numpy to **~1.0**
* relaxes tests scenario, failing on some ARM arch

## 0.1.3 (2024-03-13)

* no changes since `0.1.2`

## 0.1.2 (2023-12-18)

* add python 3.12 support (author @mentaljam, https://github.com/vincentsarago/color-operations/pull/5)

## 0.1.1 (2023-04-05)

* remove `.c` file from package
* switch linting to `ruff` and update pre-commit configuration

## 0.1.0 (2022-11-09)

* Initial release. Match rio-color 1.0.4 https://github.com/mapbox/rio-color/releases/tag/1.0.4
